Trait Catalog

pub trait Catalog {
    type Class: Default;

    // Required method
    fn style(&self, style: &Self::Class) -> Style;
}
Available on crate feature wayland and Linux and crate feature winit only.
A set of rules that dictate the style of a tooltip.

Required Associated Types

type Class: Default

The supported style of the [StyleSheet].

Required Methods

fn style(&self, style: &Self::Class) -> Style

Produces the active [Appearance] of a tooltip.

Implementors